%DECODIFICADOR RPE.
%function e=rped(Mc,xmaxc,xmc)
%Entradas:
%Mc:posición RPE codificada.
%xmaxc:valor máximo codificado.
%xmc:subsecuencia seleccionada codificada.
%Salidas:
%e:excitación residual decodificada.
function e=rped(Mc,xmaxc,xmc)
xmp=apcmdec(xmc,xmaxc);%decodificamos los términos RPE.
e=rpepos(Mc,xmp);%calculamos la excitación residual decodificada.
